Method: Rex::Exploitation::OpcodeDb::Client#modules

Defined in:
lib/rex/exploitation/opcodedb.rb

#modules(filter = {}) ⇒ Object

Returns an array of ImageModule instances. Image modules are version-specific, locale-specific, and operating system version specific image files. Modules have opcodes, segments, imports and exports associated with them. Optionally, a filter hash can be specified to limit the number of results returned from the database. If no filter hash is supplied, all modules will be returned.

LocaleNames (Array)

This hash element limits results to one or more specific locale by name.

PlatformNames (Array)

This hash element limits results to one or more specific platform by name.

ModuleNames (Array)

This hash element limits results to one or more specific module by name.

Segments (Bool)

If this hash element is set to true, the segments associated with each resulting module will be returned by the server.

Imports (Bool)

If this hash element is set to true, the imports associated with each resulting module will be returned by the server.

Exports (Bool)

If this hash element is set to true, the exports associated with each resulting module will be returned by the server.



635
636
637
# File 'lib/rex/exploitation/opcodedb.rb', line 635

def modules(filter = {})
  request('modules', filter).map { |ent| ImageModule.create(ent) }
end