Method: Rex::Post::Meterpreter::Client#init_meterpreter

Defined in:
lib/rex/post/meterpreter/client.rb

#init_meterpreter(sock, opts = {}) ⇒ Object

Initializes the meterpreter client instance



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/rex/post/meterpreter/client.rb', line 106

def init_meterpreter(sock,opts={})
  self.sock         = sock
  self.parser       = PacketParser.new
  self.ext          = ObjectAliases.new
  self.ext_aliases  = ObjectAliases.new
  self.alive        = true
  self.target_id    = opts[:target_id]
  self.capabilities = opts[:capabilities] || {}
  self.commands     = []
  self.last_checkin = Time.now

  self.conn_id      = opts[:conn_id]
  self.url          = opts[:url]
  self.ssl          = opts[:ssl]
  self.expiration   = opts[:expiration]
  self.comm_timeout = opts[:comm_timeout]
  self.retry_total  = opts[:retry_total]
  self.retry_wait   = opts[:retry_wait]
  self.passive_dispatcher = opts[:passive_dispatcher]

  self.response_timeout = opts[:timeout] || self.class.default_timeout
  self.send_keepalives  = true

  # TODO: Clarify why we don't allow unicode to be set in initial options
  # self.encode_unicode   = opts.has_key?(:encode_unicode) ? opts[:encode_unicode] : true
  self.encode_unicode = false

  # The SSL certificate is being passed down as a file path
  if opts[:ssl_cert]
    if ! ::File.exists? opts[:ssl_cert]
      elog("SSL certificate at #{opts[:ssl_cert]} does not exist and will be ignored")
    else
      # Load the certificate the same way that SslTcpServer does it
      self.ssl_cert = ::File.read(opts[:ssl_cert])
    end
  end

  if opts[:passive_dispatcher]
    initialize_passive_dispatcher

    register_extension_alias('core', ClientCore.new(self))

    initialize_inbound_handlers
    initialize_channels

    # Register the channel inbound packet handler
    register_inbound_handler(Rex::Post::Meterpreter::Channel)
  else
    # Switch the socket to SSL mode and receive the hello if needed
    if capabilities[:ssl] and not opts[:skip_ssl]
      swap_sock_plain_to_ssl()
    end

    register_extension_alias('core', ClientCore.new(self))

    initialize_inbound_handlers
    initialize_channels

    # Register the channel inbound packet handler
    register_inbound_handler(Rex::Post::Meterpreter::Channel)

    monitor_socket
  end
end