Method: Rex::IO::RingBuffer#base_sequence
- Defined in:
- lib/rex/io/ring_buffer.rb
#base_sequence ⇒ Object
The base_sequence method returns the earliest sequence number in the queue. This is zero until all slots are filled and the ring rotates.
180 181 182 183 184 185 |
# File 'lib/rex/io/ring_buffer.rb', line 180 def base_sequence self.mutex.synchronize do return 0 if not self.queue[self.beg] return self.queue[self.beg][0] end end |